@@ -9,6 +9,12 @@ from math import log
 import string
 import random
 
+import itertools
+import typing
+
+T = typing.TypeVar("T")
+
+
 logger = logging.getLogger('common_util')
 
 UNIT_LIST = zip(['bytes', 'kB', 'MB', 'GB', 'TB', 'PB'], [0, 0, 1, 2, 2, 2])
@@ -132,6 +138,35 @@ def lookahead(iterable):
     yield last, False    
     
 
+class OrderedSet(typing.MutableSet[T]):
+    """A set that preserves insertion order by internally using a dict."""
+
+    def __init__(self, iterable: typing.Iterator[T]):
+        self._d = dict.fromkeys(iterable)
+
+    def add(self, x: T) -> None:
+        self._d[x] = None
+
+    def discard(self, x: T) -> None:
+        self._d.pop(x, None)
+
+    def __contains__(self, x: object) -> bool:
+        return self._d.__contains__(x)
+
+    def __len__(self) -> int:
+        return self._d.__len__()
+
+    def __iter__(self) -> typing.Iterator[T]:
+        return self._d.__iter__()
+
+    def __str__(self):
+        return f"{{{', '.join(str(i) for i in self)}}}"
+
+    def __repr__(self):
+        return f"<OrderedSet {self}>"
+    
+    
+
         
     
 
