@@ -11,15 +11,15 @@ from google.oauth2 import service_account
 from google.protobuf import timestamp_pb2
 from trexlib.utils.security_util import create_basic_authentication, verfiy_basic_authentication
 from trexlib.utils.string_util import random_string
-from trexlib.conf import SYSTEM_TASK_SERVICE_CREDENTIAL_PATH, SYSTEM_TASK_GCLOUD_PROJECT_ID, SYSTEM_TASK_GCLOUD_LOCATION, SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL
+#from trexlib.conf import SYSTEM_TASK_SERVICE_ACCOUNT_KEY, SYSTEM_TASK_GCLOUD_PROJECT_ID, SYSTEM_TASK_GCLOUD_LOCATION, SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL
 
 logger = logging.getLogger('utils-debug')
 
 def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method='get', headers=None, 
-                credential_path=SYSTEM_TASK_SERVICE_CREDENTIAL_PATH, 
-                project_id=SYSTEM_TASK_GCLOUD_PROJECT_ID, 
-                location=SYSTEM_TASK_GCLOUD_LOCATION, 
-                service_email=SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL): 
+                credential_path=None, 
+                project_id=None, 
+                location=None, 
+                service_email=None): 
     
     cred = service_account.Credentials.from_service_account_file(
                                                             credential_path,
@@ -34,7 +34,11 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
         
     parent = client.queue_path(project_id, location, queue_name)
     
-    logger.debug(">>>>>>>>>>>>>>>>create_task: task_url=%s", task_url)
+    logger.info(">>>>>>>>>>>>>>>>create_task: task_url=%s", task_url)
+    logger.info(">>>>>>>>>>>>>>>>create_task: credential_path=%s", credential_path)
+    logger.info(">>>>>>>>>>>>>>>>create_task: project_id=%s", project_id)
+    logger.info(">>>>>>>>>>>>>>>>create_task: location=%s", location)
+    logger.info(">>>>>>>>>>>>>>>>create_task: service_email=%s", service_email)
     
     task = {
         "http_request": {  # Specify the type of request.
@@ -44,13 +48,12 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
                         }
         }
     
-    task["http_request"]["headers"] = {"Content-type": "application/json"}
-    
     if payload is not None:
         if isinstance(payload, dict):
             # Convert dict to JSON string
             payload = json.dumps(payload)
             # specify http content-type to application/json
+            task["http_request"]["headers"] = {"Content-type": "application/json"}
     
         # The API expects a payload of type bytes.
         converted_payload = payload.encode()
@@ -80,7 +83,7 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
         # Add the timestamp to the tasks.
         task["schedule_time"] = timestamp    
     
-    logger.debug('task["http_request"]["headers"]=%s', task["http_request"].get("headers"))
+    logger.info('task["http_request"]["headers"]=%s', task["http_request"].get("headers"))
     
     response = client.create_task(request={"parent": parent, "task": task})
     
