@@ -4,6 +4,7 @@ Created on Jul 3, 2012
 @author: sglok
 '''
 import random, re, string, logging
+import hmac
 
 WHITESPACE_PATTERN  = re.compile(r'\s')
 DASH_PATTERN        = re.compile(r'-')
@@ -14,6 +15,22 @@ NUMERIC_CHARS       = string.digits
 HUMAN_SAFE_ALPHANUMERIC_CHARS     = 'abcdefghijkmnpqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ123456789'
 
 
+
+def safe_str_cmp(a: str, b: str) -> bool:
+    """This function compares strings in somewhat constant time. This
+    requires that the length of at least one string is known in advance.
+
+    Returns `True` if the two strings are equal, or `False` if they are not.
+    """
+
+    if isinstance(a, str):
+        a = a.encode("utf-8")  # type: ignore
+
+    if isinstance(b, str):
+        b = b.encode("utf-8")  # type: ignore
+
+    return hmac.compare_digest(a, b)
+
 def random_string(number_character, is_human_mistake_safe=False):
     if is_human_mistake_safe:
         if number_character and type(number_character) is int and number_character>=0:
